/*******************************************************************************
 * Copyright (c) 2003, 2007 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/

/*
 * Created on : 23.06.2003
 * Created by : s3595
 */
package at.spardat.xma.boot.component;

import java.util.Properties;

import at.spardat.xma.boot.comp.AppContainer;

/**
 * This is the interface used by the boot runtime to
 * communicate with an application-session of the runtime.
 *
 * @author <a href="mailto:schaeferc@spardat.at">s3595 Chr. Schaefer (CGS)</a>
 * @version $Id: IRtXMASessionClient.java 2084 2007-11-27 14:53:31Z s3460 $
 */
public interface IRtXMASessionClient {

    /**
     * Login method for runtime versions befor 1.7.0
     * The boot runtime will call login for each application on startup.
     *
     * @return  boolean returns false if the login has failed
     * @deprecated
     */
    public boolean login();

    /**
     * Login method for runtime version 1.7.0 and newer.
     * The boot runtime will call login for each application on startup.
     *
     * @param properties All properties send to the first component.
     *      The LoginModule can be parametrized by them.
     * @return  boolean returns false if the login has failed
     */
    public boolean login(Properties properties);

    /**
     * The boot runtime calls logout after the last component is closed and
     * the application will be deleted.
     */
    public void logout();

    /**
     * get the application container object, that holds information about
     * this application
     *
     * @return   AppContainer
     */
    public AppContainer getAppContainer();

    /**
     * Gets the id of the session; with http-comunication this is
     * the session cookie.
     * @return the id of the session
     */
    public String getId();

    /**
     * Sets the id of the session; with http-comunication this is
     * the session cookie. This method must only be called by the runtime!
     *
     * @param id the new session id.
     */
    public void setId(String id);

    /**
     * Reverse the transformations, e.g. compression, applied at the server.
     * @param transform string encoded names of transformations applied at the server
     * @param data original data
     * @return result of the inverse transformations applied on the data
     */
    public byte[] inverseTransform(String transform, byte[] data);

}


